const APIRequest = require('./APIRequest.model')

class RequestError extends APIRequest {
    static get schema() {
        return {
            ...super.schema,
            error: {
                message: String,
                stack: [String],
                context: Object,
            }
        }
    }

    static async log(req, { status_code, message, error }) {
        const log = await super.log(req, { status_code, message, data: {} })

        if ( !(error instanceof Error ) ) return log

        log.error = {
            message: `${error.name}: ${error.message}`,
            stack: error.stack.split(/\sat\s/).slice(1).map(x => x.trim()),
            context: error?.context || {},
        }

        await log.save()
        return log
    }
}

module.exports = exports = RequestError
